<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Nastavení modulu stavové ikony</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Show message</source>
        <translation>Zobrazovat zprávu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="27"/>
        <source>Show tooltip</source>
        <translation>Zobrazovat tooltip</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Message delay, ms:</source>
        <translation>Prodleva zprávy, ms:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Use standard icons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="46"/>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="47"/>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="48"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="49"/>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="50"/>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="52"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="127"/>
        <source>Now Playing</source>
        <translation>Nyní hraje</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Modul stavové ikony</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Modul stavové ikony Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>O modulu stavové ikony</translation>
    </message>
</context>
</TS>
